@@ -19,7 +19,7 @@ use {
     },
 };
 
-mod git;
+pub mod git;
 
 /// Would you like to SAVE the change?
 ///
@@ -28,6 +28,10 @@ mod git;
 #[clap(version)]
 #[remain::sorted]
 pub struct Args {
+    /// Prepare the commit, but don't actually save anything to disk.
+    #[clap(long)]
+    pub dry_run: bool,
+
     /// The author email to use for the commit.
     ///
     /// [default: email from git, or else from parent commit, or else "save"]
@@ -219,7 +223,11 @@ pub fn main(args: Args) -> Result<()> {
         }
     }
 
-    index.write()?;
+    if !args.dry_run {
+        index.write()?;
+    } else {
+        info!("Skipping index write because this is a dry run.");
+    }
 
     let tree4 = &tree.to_string()[..4];
     let tree = repo.find_tree(tree)?;
@@ -312,24 +320,28 @@ pub fn main(args: Args) -> Result<()> {
         .unwrap();
     drop(trace_brute);
 
-    repo.commit(
-        Some("HEAD"),
-        &Signature::new(
-            &user_name,
-            &user_email,
-            &Time::new(author_timestamp, offset),
-        )
-        .unwrap(),
-        &Signature::new(
-            &user_name,
-            &user_email,
-            &Time::new(commit_timestamp, offset),
-        )
-        .unwrap(),
-        &message,
-        &tree,
-        parents,
-    )?;
+    if !args.dry_run {
+        repo.commit(
+            Some("HEAD"),
+            &Signature::new(
+                &user_name,
+                &user_email,
+                &Time::new(author_timestamp, offset),
+            )
+            .unwrap(),
+            &Signature::new(
+                &user_name,
+                &user_email,
+                &Time::new(commit_timestamp, offset),
+            )
+            .unwrap(),
+            &message,
+            &tree,
+            parents,
+        )?;
+    } else {
+        info!("Skipping commit write because this is a dry run.");
+    }
 
     eprintln!();
 
